(function ($) {
    "use strict";

    $(document).on("click", ".pe-wishlist-btn", function (e) {
        e.preventDefault();
        let productId = $(this).data("product-id");
        let btn = $(this);

        btn.addClass("loading");

        let isLoggedIn = woocommerce_params.is_user_logged_in === "1";

        if (isLoggedIn) {

            $.ajax({
                url: woocommerce_params.ajax_url,
                type: "POST",
                data: {
                    action: "pe_toggle_wishlist",
                    product_id: productId,
                },
                dataType: "json",
                success: function (data) {
                    if (data.success) {
                        btn.removeClass("loading");

                        document.dispatchEvent(new CustomEvent("wishlistUpdated"));

                        setTimeout(() => {
                            if (data.data.status === "added") {
                                btn.addClass("in--wishlist");
                            } else if (data.data.status === "removed") {
                                btn.removeClass("in--wishlist");
                            }


                        }, 10);
                    }
                },
            });
        } else {

            btn.addClass("loading");

            setTimeout(() => {

                let wishlist = getWishlistCookie();

                if (wishlist.includes(productId)) {
                    wishlist = wishlist.filter((id) => id !== productId);
                    btn.removeClass("in--wishlist");
                } else {
                    wishlist.push(productId);
                    btn.addClass("in--wishlist");
                }
                setWishlistCookie(wishlist);
                btn.removeClass("loading");

                document.dispatchEvent(new CustomEvent("wishlistUpdated"));

            }, 1000);


        }
    });

    function getWishlistCookie() {
        let cookieValue = document.cookie
            .split("; ")
            .find((row) => row.startsWith("pe_wishlist="));

        return cookieValue ? JSON.parse(decodeURIComponent(cookieValue.split("=")[1])) : [];
    }

    function setWishlistCookie(wishlist) {
        document.cookie = `pe_wishlist=${encodeURIComponent(JSON.stringify(wishlist))}; path=/; max-age=${30 * 24 * 60 * 60}`;
    }


    document.addEventListener("wishlistUpdated", function () {
        if (document.querySelector('.pe--wishlist')) {
            var url = new URL(window.location.href);


            let wishlist = getWishlistCookie();
            url.searchParams.delete("wish");
            wishlist.forEach(id => url.searchParams.append("wish[]", id));

            var currentWrapper = document.querySelectorAll('.pe--wishlist');

            $.ajax({
                url: url.toString(),
                type: 'GET',
                dataType: 'html',
                success: function (response) {
                    var doc = $('<div>').html(response);
                    var newProducts = doc.find('.pe--wishlist');

                    currentWrapper.forEach(wrap => {
                        wrap.innerHTML = newProducts[0].innerHTML;

                        if (wrap.querySelector('.product--archive--gallery')) {
                            let swiperCont = wrap.querySelectorAll('.product--archive--gallery');
                            swiperCont.forEach(cont => {
                                new Swiper(cont, {
                                    slidesPerView: 1,
                                    speed: 750,
                                    navigation: {
                                        nextEl: cont.querySelector('.pag--next'),
                                        prevEl: cont.querySelector('.pag--prev'),
                                    },
                                });
                            });
                        }
                    });
                }
            });
        }
    });


    function getWishlistCookie() {
        let cookieValue = document.cookie
            .split("; ")
            .find(row => row.startsWith("pe_wishlist="));

        return cookieValue ? JSON.parse(decodeURIComponent(cookieValue.split("=")[1])) : [];
    }


}(jQuery));

