<?php
/**
 * Cart totals
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart-totals.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 2.3.6
 */

defined('ABSPATH') || exit;

?>  

<div class="cart_totals <?php echo (WC()->customer->has_calculated_shipping()) ? 'calculated_shipping' : ''; ?>">

    <?php do_action('woocommerce_before_cart_totals'); ?>

    <div class="cart-summary">

        <div class="cart-row cart-subtotal">
            <span class="cart-label"><?php esc_html_e('Subtotal', 'woocommerce'); ?></span>
            <span class="cart-value"><?php wc_cart_totals_subtotal_html(); ?></span>
        </div>

        <?php if (WC()->cart->needs_shipping() && WC()->cart->show_shipping()): ?>

            <?php do_action('woocommerce_cart_totals_before_shipping'); ?>
            <div class="cart-row cart-shipping">
                <?php wc_cart_totals_shipping_html(); ?>
            </div>
            <?php do_action('woocommerce_cart_totals_after_shipping'); ?>

        <?php elseif (WC()->cart->needs_shipping() && 'yes' === get_option('woocommerce_enable_shipping_calc')): ?>
            <div class="cart-row cart-shipping">
                <span class="cart-label"><?php esc_html_e('Shipping', 'woocommerce'); ?></span>
                <span class="cart-value"><?php woocommerce_shipping_calculator(); ?></span>
            </div>
        <?php endif; ?>

        <?php foreach (WC()->cart->get_fees() as $fee): ?>
            <div class="cart-row cart-fee">
                <span class="cart-label"><?php echo esc_html($fee->name); ?></span>
                <span class="cart-value"><?php wc_cart_totals_fee_html($fee); ?></span>
            </div>
        <?php endforeach; ?>

        <?php if (wc_tax_enabled() && !WC()->cart->display_prices_including_tax()) : ?>
            <?php
            $taxable_address = WC()->customer->get_taxable_address();
            $estimated_text = '';

            if (WC()->customer->is_customer_outside_base() && !WC()->customer->has_calculated_shipping()) {
                $estimated_text = sprintf(' <small>' . esc_html__('(estimated for %s)', 'woocommerce') . '</small>', WC()->countries->estimated_for_prefix($taxable_address[0]) . WC()->countries->countries[$taxable_address[0]]);
            }
            ?>
            <?php if ('itemized' === get_option('woocommerce_tax_total_display')) : ?>
                <?php foreach (WC()->cart->get_tax_totals() as $code => $tax) : ?>
                    <div class="cart-row tax-rate tax-rate-<?php echo esc_attr(sanitize_title($code)); ?>">
                        <span class="cart-label"><?php echo esc_html($tax->label) . $estimated_text; ?></span>
                        <span class="cart-value"><?php echo wp_kses_post($tax->formatted_amount); ?></span>
                    </div>
                <?php endforeach; ?>
            <?php else : ?>
                <div class="cart-row cart-tax">
                    <span class="cart-label"><?php echo esc_html(WC()->countries->tax_or_vat()) . $estimated_text; ?></span>
                    <span class="cart-value"><?php wc_cart_totals_taxes_total_html(); ?></span>
                </div>
            <?php endif; ?>
        <?php endif; ?>

        <?php if (wc_coupons_enabled()) { ?>
            <div class="cart-row saren--coupon--register">
                <div class="saren--coupon">
                    <input type="text" name="saren_coupon_code" class="input-text" id="saren_coupon_code" value=""
                        placeholder="<?php esc_attr_e('Coupon code', 'woocommerce'); ?>" />
                    <button type="submit" class="button" name="apply_coupon"
                        value="<?php esc_attr_e('Apply coupon', 'woocommerce'); ?>"><?php esc_html_e('Apply coupon', 'woocommerce'); ?></button>
                </div>
            </div>
        <?php } ?>

        <?php foreach (WC()->cart->get_coupons() as $code => $coupon): ?>
            <div class="cart-row cart-discount coupon-<?php echo esc_attr(sanitize_title($code)); ?>">
                <span class="cart-label"><?php wc_cart_totals_coupon_label($coupon); ?></span>
                <span class="cart-value"><?php wc_cart_totals_coupon_html($coupon); ?></span>
            </div>
        <?php endforeach; ?>

        <?php do_action('woocommerce_cart_totals_before_order_total'); ?>

        <div class="cart-row order-total">
            <span class="cart-label"><?php esc_html_e('Total', 'woocommerce'); ?></span>
            <span class="cart-value"><?php wc_cart_totals_order_total_html(); ?></span>
        </div>

        <?php do_action('woocommerce_cart_totals_after_order_total'); ?>

    </div>

    <div class="wc-proceed-to-checkout">
        <?php do_action('woocommerce_proceed_to_checkout'); ?>
    </div>

    <?php do_action('woocommerce_after_cart_totals'); ?>

</div>
